@@ -23,10 +23,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner",
-    "1.94.24",
-    __name__[0:-6],
-    "cdk-gitlab-runner@1.94.24.jsii.tgz",
+    "cdk-gitlab-runner", "1.95.4", __name__[0:-6], "cdk-gitlab-runner@1.95.4.jsii.tgz"
 )
 
 __all__ = [
